@@ -201,7 +201,7 @@ class BankingExtension(Extension):
             is_redirect=False,  
             locale=g.language, 
             _source=['title', 'path', 'alt_title', 'custom_text', 'logo'],
-            collection_mode='CasinoBanking',
+            collection_mode=['CasinoBanking', 'CasinoBankingLimits'],
             _count=100,
             _sort=[
                 {'alt_title.keyword': {'order': 'asc'}}
@@ -611,7 +611,7 @@ class TopAlexaExtension(Extension):
             is_searchable=True,
             is_redirect=False,  
             locale=g.language, 
-            _source=['title', 'path', 'alt_title', 'rank_alexa', 'geo'],
+            _source=['title', 'path', 'alias', 'alt_title', 'rank_alexa', 'geo'],
             _count=30,
             _sort=[
                 {'rank_alexa': {'order': 'asc'}}
