@@ -1554,6 +1554,7 @@ class CasinoCommit(ElasticEntity):
         'games': list,
         'games_count': int,
         'games_limits': list,
+        'cashiers_limits': list,
         'software': list,
         'currencies': list,
         'default_currency': str,
@@ -1696,6 +1697,7 @@ class CasinoModel(BaseModel):
     games: List[str] = []
     games_count: Optional[int]
     games_limits: List[dict] = []
+    cashiers_limits: List[dict] = []
     software: List[str] = []
     currencies: conlist(str, min_items=1)
     default_currency: str
@@ -1798,6 +1800,7 @@ class ActivityComplaintModel(BaseModel):
     amount: str = ...
     currency: str = ...
     message: str = ...
+    subject: str = ...
     username: str = ...
     email: EmailStr
 
@@ -1818,6 +1821,7 @@ class ComplaintModel(BaseModel):
     currency: str = ...
     message: str = ...
     status: str = ...
+    subject: Optional[str] = None
     ip: str = ...
     is_active: bool = False
     rate: Optional[conint(ge=1, le=5)] = None
